/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://code.google.com/p/google-apis-client-generator/
 * (build: 2013-06-20 19:08:55 UTC)
 * on 2013-06-25 at 21:57:01 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.adsense;

/**
 * Service definition for AdSense (v1.3).
 *
 * <p>
 * Gives AdSense publishers access to their inventory and the ability to generate reports
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/adsense/management/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link AdSenseRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class AdSense extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION == 14,
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.14 of google-api-client to run version " +
        "1.14.2-beta of the AdSense Management API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "adsense/v1.3/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public AdSense(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  AdSense(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Accounts collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Accounts.List request = adsense.accounts().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Accounts accounts() {
    return new Accounts();
  }

  /**
   * The "accounts" collection of methods.
   */
  public class Accounts {

    /**
     * Get information about the selected AdSense account.
     *
     * Create a request for the method "accounts.get".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param accountId Account to get information about.
     * @return the request
     */
    public Get get(java.lang.String accountId) throws java.io.IOException {
      Get result = new Get(accountId);
      initialize(result);
      return result;
    }

    public class Get extends AdSenseRequest<com.google.api.services.adsense.model.Account> {

      private static final String REST_PATH = "accounts/{accountId}";

      /**
       * Get information about the selected AdSense account.
       *
       * Create a request for the method "accounts.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param accountId Account to get information about.
       * @since 1.13
       */
      protected Get(java.lang.String accountId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.Account.class);
        this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Account to get information about. */
      @com.google.api.client.util.Key
      private java.lang.String accountId;

      /** Account to get information about.
       */
      public java.lang.String getAccountId() {
        return accountId;
      }

      /** Account to get information about. */
      public Get setAccountId(java.lang.String accountId) {
        this.accountId = accountId;
        return this;
      }

      /** Whether the tree of sub accounts should be returned. */
      @com.google.api.client.util.Key
      private java.lang.Boolean tree;

      /** Whether the tree of sub accounts should be returned.
       */
      public java.lang.Boolean getTree() {
        return tree;
      }

      /** Whether the tree of sub accounts should be returned. */
      public Get setTree(java.lang.Boolean tree) {
        this.tree = tree;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * List all accounts available to this AdSense account.
     *
     * Create a request for the method "accounts.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.Accounts> {

      private static final String REST_PATH = "accounts";

      /**
       * List all accounts available to this AdSense account.
       *
       * Create a request for the method "accounts.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.Accounts.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
       * A continuation token, used to page through accounts. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** A continuation token, used to page through accounts. To retrieve the next page, set this parameter
     to the value of "nextPageToken" from the previous response.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * A continuation token, used to page through accounts. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of accounts to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of accounts to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of accounts to include in the response, used for paging. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the Adclients collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Adclients.List request = adsense.adclients().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Adclients adclients() {
      return new Adclients();
    }

    /**
     * The "adclients" collection of methods.
     */
    public class Adclients {

      /**
       * List all ad clients in the specified account.
       *
       * Create a request for the method "adclients.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param accountId Account for which to list ad clients.
       * @return the request
       */
      public List list(java.lang.String accountId) throws java.io.IOException {
        List result = new List(accountId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.AdClients> {

        private static final String REST_PATH = "accounts/{accountId}/adclients";

        /**
         * List all ad clients in the specified account.
         *
         * Create a request for the method "adclients.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account for which to list ad clients.
         * @since 1.13
         */
        protected List(java.lang.String accountId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdClients.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Account for which to list ad clients. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account for which to list ad clients.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account for which to list ad clients. */
        public List setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /**
         * A continuation token, used to page through ad clients. To retrieve the next page, set
         * this parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through ad clients. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through ad clients. To retrieve the next page, set
         * this parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of ad clients to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of ad clients to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of ad clients to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the Adunits collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Adunits.List request = adsense.adunits().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Adunits adunits() {
      return new Adunits();
    }

    /**
     * The "adunits" collection of methods.
     */
    public class Adunits {

      /**
       * Gets the specified ad unit in the specified ad client for the specified account.
       *
       * Create a request for the method "adunits.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param accountId Account to which the ad client belongs.
       * @param adClientId Ad client for which to get the ad unit.
       * @param adUnitId Ad unit to retrieve.
       * @return the request
       */
      public Get get(java.lang.String accountId, java.lang.String adClientId, java.lang.String adUnitId) throws java.io.IOException {
        Get result = new Get(accountId, adClientId, adUnitId);
        initialize(result);
        return result;
      }

      public class Get extends AdSenseRequest<com.google.api.services.adsense.model.AdUnit> {

        private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/adunits/{adUnitId}";

        /**
         * Gets the specified ad unit in the specified ad client for the specified account.
         *
         * Create a request for the method "adunits.get".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client for which to get the ad unit.
         * @param adUnitId Ad unit to retrieve.
         * @since 1.13
         */
        protected Get(java.lang.String accountId, java.lang.String adClientId, java.lang.String adUnitId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdUnit.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.adUnitId = com.google.api.client.util.Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(java.lang.String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** Account to which the ad client belongs. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account to which the ad client belongs.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account to which the ad client belongs. */
        public Get setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Ad client for which to get the ad unit. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client for which to get the ad unit.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client for which to get the ad unit. */
        public Get setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Ad unit to retrieve. */
        @com.google.api.client.util.Key
        private java.lang.String adUnitId;

        /** Ad unit to retrieve.
         */
        public java.lang.String getAdUnitId() {
          return adUnitId;
        }

        /** Ad unit to retrieve. */
        public Get setAdUnitId(java.lang.String adUnitId) {
          this.adUnitId = adUnitId;
          return this;
        }

        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Get ad code for the specified ad unit.
       *
       * Create a request for the method "adunits.getAdCode".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link GetAdCode#execute()} method to invoke the remote operation.
       *
       * @param accountId Account which contains the ad client.
       * @param adClientId Ad client with contains the ad unit.
       * @param adUnitId Ad unit to get the code for.
       * @return the request
       */
      public GetAdCode getAdCode(java.lang.String accountId, java.lang.String adClientId, java.lang.String adUnitId) throws java.io.IOException {
        GetAdCode result = new GetAdCode(accountId, adClientId, adUnitId);
        initialize(result);
        return result;
      }

      public class GetAdCode extends AdSenseRequest<com.google.api.services.adsense.model.AdCode> {

        private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/adunits/{adUnitId}/adcode";

        /**
         * Get ad code for the specified ad unit.
         *
         * Create a request for the method "adunits.getAdCode".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link GetAdCode#execute()} method to invoke the remote operation. <p>
         * {@link
         * GetAdCode#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account which contains the ad client.
         * @param adClientId Ad client with contains the ad unit.
         * @param adUnitId Ad unit to get the code for.
         * @since 1.13
         */
        protected GetAdCode(java.lang.String accountId, java.lang.String adClientId, java.lang.String adUnitId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdCode.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.adUnitId = com.google.api.client.util.Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public GetAdCode setAlt(java.lang.String alt) {
          return (GetAdCode) super.setAlt(alt);
        }

        @Override
        public GetAdCode setFields(java.lang.String fields) {
          return (GetAdCode) super.setFields(fields);
        }

        @Override
        public GetAdCode setKey(java.lang.String key) {
          return (GetAdCode) super.setKey(key);
        }

        @Override
        public GetAdCode setOauthToken(java.lang.String oauthToken) {
          return (GetAdCode) super.setOauthToken(oauthToken);
        }

        @Override
        public GetAdCode setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (GetAdCode) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public GetAdCode setQuotaUser(java.lang.String quotaUser) {
          return (GetAdCode) super.setQuotaUser(quotaUser);
        }

        @Override
        public GetAdCode setUserIp(java.lang.String userIp) {
          return (GetAdCode) super.setUserIp(userIp);
        }

        /** Account which contains the ad client. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account which contains the ad client.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account which contains the ad client. */
        public GetAdCode setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Ad client with contains the ad unit. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client with contains the ad unit.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client with contains the ad unit. */
        public GetAdCode setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Ad unit to get the code for. */
        @com.google.api.client.util.Key
        private java.lang.String adUnitId;

        /** Ad unit to get the code for.
         */
        public java.lang.String getAdUnitId() {
          return adUnitId;
        }

        /** Ad unit to get the code for. */
        public GetAdCode setAdUnitId(java.lang.String adUnitId) {
          this.adUnitId = adUnitId;
          return this;
        }

        @Override
        public GetAdCode set(String parameterName, Object value) {
          return (GetAdCode) super.set(parameterName, value);
        }
      }
      /**
       * List all ad units in the specified ad client for the specified account.
       *
       * Create a request for the method "adunits.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param accountId Account to which the ad client belongs.
       * @param adClientId Ad client for which to list ad units.
       * @return the request
       */
      public List list(java.lang.String accountId, java.lang.String adClientId) throws java.io.IOException {
        List result = new List(accountId, adClientId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.AdUnits> {

        private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/adunits";

        /**
         * List all ad units in the specified ad client for the specified account.
         *
         * Create a request for the method "adunits.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client for which to list ad units.
         * @since 1.13
         */
        protected List(java.lang.String accountId, java.lang.String adClientId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdUnits.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Account to which the ad client belongs. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account to which the ad client belongs.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account to which the ad client belongs. */
        public List setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Ad client for which to list ad units. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client for which to list ad units.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client for which to list ad units. */
        public List setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Whether to include inactive ad units. Default: true. */
        @com.google.api.client.util.Key
        private java.lang.Boolean includeInactive;

        /** Whether to include inactive ad units. Default: true.
         */
        public java.lang.Boolean getIncludeInactive() {
          return includeInactive;
        }

        /** Whether to include inactive ad units. Default: true. */
        public List setIncludeInactive(java.lang.Boolean includeInactive) {
          this.includeInactive = includeInactive;
          return this;
        }

        /**
         * A continuation token, used to page through ad units. To retrieve the next page, set this
         * parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through ad units. To retrieve the next page, set this parameter
       to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through ad units. To retrieve the next page, set this
         * parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of ad units to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of ad units to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of ad units to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

      /**
       * An accessor for creating requests from the Customchannels collection.
       *
       * <p>The typical use is:</p>
       * <pre>
       *   {@code AdSense adsense = new AdSense(...);}
       *   {@code AdSense.Customchannels.List request = adsense.customchannels().list(parameters ...)}
       * </pre>
       *
       * @return the resource collection
       */
      public Customchannels customchannels() {
        return new Customchannels();
      }

      /**
       * The "customchannels" collection of methods.
       */
      public class Customchannels {

        /**
         * List all custom channels which the specified ad unit belongs to.
         *
         * Create a request for the method "customchannels.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation.
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client which contains the ad unit.
         * @param adUnitId Ad unit for which to list custom channels.
         * @return the request
         */
        public List list(java.lang.String accountId, java.lang.String adClientId, java.lang.String adUnitId) throws java.io.IOException {
          List result = new List(accountId, adClientId, adUnitId);
          initialize(result);
          return result;
        }

        public class List extends AdSenseRequest<com.google.api.services.adsense.model.CustomChannels> {

          private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/adunits/{adUnitId}/customchannels";

          /**
           * List all custom channels which the specified ad unit belongs to.
           *
           * Create a request for the method "customchannels.list".
           *
           * This request holds the parameters needed by the the adsense server.  After setting any optional
           * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
           * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
           * called to initialize this instance immediately after invoking the constructor. </p>
           *
           * @param accountId Account to which the ad client belongs.
           * @param adClientId Ad client which contains the ad unit.
           * @param adUnitId Ad unit for which to list custom channels.
           * @since 1.13
           */
          protected List(java.lang.String accountId, java.lang.String adClientId, java.lang.String adUnitId) {
            super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.CustomChannels.class);
            this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
            this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
            this.adUnitId = com.google.api.client.util.Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
          }

          @Override
          public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
            return super.executeUsingHead();
          }

          @Override
          public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
            return super.buildHttpRequestUsingHead();
          }

          @Override
          public List setAlt(java.lang.String alt) {
            return (List) super.setAlt(alt);
          }

          @Override
          public List setFields(java.lang.String fields) {
            return (List) super.setFields(fields);
          }

          @Override
          public List setKey(java.lang.String key) {
            return (List) super.setKey(key);
          }

          @Override
          public List setOauthToken(java.lang.String oauthToken) {
            return (List) super.setOauthToken(oauthToken);
          }

          @Override
          public List setPrettyPrint(java.lang.Boolean prettyPrint) {
            return (List) super.setPrettyPrint(prettyPrint);
          }

          @Override
          public List setQuotaUser(java.lang.String quotaUser) {
            return (List) super.setQuotaUser(quotaUser);
          }

          @Override
          public List setUserIp(java.lang.String userIp) {
            return (List) super.setUserIp(userIp);
          }

          /** Account to which the ad client belongs. */
          @com.google.api.client.util.Key
          private java.lang.String accountId;

          /** Account to which the ad client belongs.
           */
          public java.lang.String getAccountId() {
            return accountId;
          }

          /** Account to which the ad client belongs. */
          public List setAccountId(java.lang.String accountId) {
            this.accountId = accountId;
            return this;
          }

          /** Ad client which contains the ad unit. */
          @com.google.api.client.util.Key
          private java.lang.String adClientId;

          /** Ad client which contains the ad unit.
           */
          public java.lang.String getAdClientId() {
            return adClientId;
          }

          /** Ad client which contains the ad unit. */
          public List setAdClientId(java.lang.String adClientId) {
            this.adClientId = adClientId;
            return this;
          }

          /** Ad unit for which to list custom channels. */
          @com.google.api.client.util.Key
          private java.lang.String adUnitId;

          /** Ad unit for which to list custom channels.
           */
          public java.lang.String getAdUnitId() {
            return adUnitId;
          }

          /** Ad unit for which to list custom channels. */
          public List setAdUnitId(java.lang.String adUnitId) {
            this.adUnitId = adUnitId;
            return this;
          }

          /**
           * A continuation token, used to page through custom channels. To retrieve the next page,
           * set this parameter to the value of "nextPageToken" from the previous response.
           */
          @com.google.api.client.util.Key
          private java.lang.String pageToken;

          /** A continuation token, used to page through custom channels. To retrieve the next page, set this
         parameter to the value of "nextPageToken" from the previous response.
           */
          public java.lang.String getPageToken() {
            return pageToken;
          }

          /**
           * A continuation token, used to page through custom channels. To retrieve the next page,
           * set this parameter to the value of "nextPageToken" from the previous response.
           */
          public List setPageToken(java.lang.String pageToken) {
            this.pageToken = pageToken;
            return this;
          }

          /** The maximum number of custom channels to include in the response, used for paging. */
          @com.google.api.client.util.Key
          private java.lang.Integer maxResults;

          /** The maximum number of custom channels to include in the response, used for paging.

         [minimum: 0] [maximum: 10000]
           */
          public java.lang.Integer getMaxResults() {
            return maxResults;
          }

          /** The maximum number of custom channels to include in the response, used for paging. */
          public List setMaxResults(java.lang.Integer maxResults) {
            this.maxResults = maxResults;
            return this;
          }

          @Override
          public List set(String parameterName, Object value) {
            return (List) super.set(parameterName, value);
          }
        }

      }
    }
    /**
     * An accessor for creating requests from the Alerts collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Alerts.List request = adsense.alerts().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Alerts alerts() {
      return new Alerts();
    }

    /**
     * The "alerts" collection of methods.
     */
    public class Alerts {

      /**
       * List the alerts for the specified AdSense account.
       *
       * Create a request for the method "alerts.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param accountId Account for which to retrieve the alerts.
       * @return the request
       */
      public List list(java.lang.String accountId) throws java.io.IOException {
        List result = new List(accountId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.Alerts> {

        private static final String REST_PATH = "accounts/{accountId}/alerts";

        /**
         * List the alerts for the specified AdSense account.
         *
         * Create a request for the method "alerts.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account for which to retrieve the alerts.
         * @since 1.13
         */
        protected List(java.lang.String accountId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.Alerts.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Account for which to retrieve the alerts. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account for which to retrieve the alerts.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account for which to retrieve the alerts. */
        public List setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /**
         * The locale to use for translating alert messages. The account locale will be used if this
         * is not supplied. The AdSense default (English) will be used if the supplied locale is
         * invalid or unsupported.
         */
        @com.google.api.client.util.Key
        private java.lang.String locale;

        /** The locale to use for translating alert messages. The account locale will be used if this is not
       supplied. The AdSense default (English) will be used if the supplied locale is invalid or
       unsupported.
         */
        public java.lang.String getLocale() {
          return locale;
        }

        /**
         * The locale to use for translating alert messages. The account locale will be used if this
         * is not supplied. The AdSense default (English) will be used if the supplied locale is
         * invalid or unsupported.
         */
        public List setLocale(java.lang.String locale) {
          this.locale = locale;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the Customchannels collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Customchannels.List request = adsense.customchannels().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Customchannels customchannels() {
      return new Customchannels();
    }

    /**
     * The "customchannels" collection of methods.
     */
    public class Customchannels {

      /**
       * Get the specified custom channel from the specified ad client for the specified account.
       *
       * Create a request for the method "customchannels.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param accountId Account to which the ad client belongs.
       * @param adClientId Ad client which contains the custom channel.
       * @param customChannelId Custom channel to retrieve.
       * @return the request
       */
      public Get get(java.lang.String accountId, java.lang.String adClientId, java.lang.String customChannelId) throws java.io.IOException {
        Get result = new Get(accountId, adClientId, customChannelId);
        initialize(result);
        return result;
      }

      public class Get extends AdSenseRequest<com.google.api.services.adsense.model.CustomChannel> {

        private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/customchannels/{customChannelId}";

        /**
         * Get the specified custom channel from the specified ad client for the specified account.
         *
         * Create a request for the method "customchannels.get".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client which contains the custom channel.
         * @param customChannelId Custom channel to retrieve.
         * @since 1.13
         */
        protected Get(java.lang.String accountId, java.lang.String adClientId, java.lang.String customChannelId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.CustomChannel.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.customChannelId = com.google.api.client.util.Preconditions.checkNotNull(customChannelId, "Required parameter customChannelId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(java.lang.String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** Account to which the ad client belongs. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account to which the ad client belongs.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account to which the ad client belongs. */
        public Get setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Ad client which contains the custom channel. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client which contains the custom channel.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client which contains the custom channel. */
        public Get setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Custom channel to retrieve. */
        @com.google.api.client.util.Key
        private java.lang.String customChannelId;

        /** Custom channel to retrieve.
         */
        public java.lang.String getCustomChannelId() {
          return customChannelId;
        }

        /** Custom channel to retrieve. */
        public Get setCustomChannelId(java.lang.String customChannelId) {
          this.customChannelId = customChannelId;
          return this;
        }

        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * List all custom channels in the specified ad client for the specified account.
       *
       * Create a request for the method "customchannels.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param accountId Account to which the ad client belongs.
       * @param adClientId Ad client for which to list custom channels.
       * @return the request
       */
      public List list(java.lang.String accountId, java.lang.String adClientId) throws java.io.IOException {
        List result = new List(accountId, adClientId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.CustomChannels> {

        private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/customchannels";

        /**
         * List all custom channels in the specified ad client for the specified account.
         *
         * Create a request for the method "customchannels.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client for which to list custom channels.
         * @since 1.13
         */
        protected List(java.lang.String accountId, java.lang.String adClientId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.CustomChannels.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Account to which the ad client belongs. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account to which the ad client belongs.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account to which the ad client belongs. */
        public List setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Ad client for which to list custom channels. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client for which to list custom channels.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client for which to list custom channels. */
        public List setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /**
         * A continuation token, used to page through custom channels. To retrieve the next page,
         * set this parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through custom channels. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through custom channels. To retrieve the next page,
         * set this parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of custom channels to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of custom channels to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of custom channels to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

      /**
       * An accessor for creating requests from the Adunits collection.
       *
       * <p>The typical use is:</p>
       * <pre>
       *   {@code AdSense adsense = new AdSense(...);}
       *   {@code AdSense.Adunits.List request = adsense.adunits().list(parameters ...)}
       * </pre>
       *
       * @return the resource collection
       */
      public Adunits adunits() {
        return new Adunits();
      }

      /**
       * The "adunits" collection of methods.
       */
      public class Adunits {

        /**
         * List all ad units in the specified custom channel.
         *
         * Create a request for the method "adunits.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation.
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client which contains the custom channel.
         * @param customChannelId Custom channel for which to list ad units.
         * @return the request
         */
        public List list(java.lang.String accountId, java.lang.String adClientId, java.lang.String customChannelId) throws java.io.IOException {
          List result = new List(accountId, adClientId, customChannelId);
          initialize(result);
          return result;
        }

        public class List extends AdSenseRequest<com.google.api.services.adsense.model.AdUnits> {

          private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/customchannels/{customChannelId}/adunits";

          /**
           * List all ad units in the specified custom channel.
           *
           * Create a request for the method "adunits.list".
           *
           * This request holds the parameters needed by the the adsense server.  After setting any optional
           * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
           * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
           * called to initialize this instance immediately after invoking the constructor. </p>
           *
           * @param accountId Account to which the ad client belongs.
           * @param adClientId Ad client which contains the custom channel.
           * @param customChannelId Custom channel for which to list ad units.
           * @since 1.13
           */
          protected List(java.lang.String accountId, java.lang.String adClientId, java.lang.String customChannelId) {
            super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdUnits.class);
            this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
            this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
            this.customChannelId = com.google.api.client.util.Preconditions.checkNotNull(customChannelId, "Required parameter customChannelId must be specified.");
          }

          @Override
          public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
            return super.executeUsingHead();
          }

          @Override
          public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
            return super.buildHttpRequestUsingHead();
          }

          @Override
          public List setAlt(java.lang.String alt) {
            return (List) super.setAlt(alt);
          }

          @Override
          public List setFields(java.lang.String fields) {
            return (List) super.setFields(fields);
          }

          @Override
          public List setKey(java.lang.String key) {
            return (List) super.setKey(key);
          }

          @Override
          public List setOauthToken(java.lang.String oauthToken) {
            return (List) super.setOauthToken(oauthToken);
          }

          @Override
          public List setPrettyPrint(java.lang.Boolean prettyPrint) {
            return (List) super.setPrettyPrint(prettyPrint);
          }

          @Override
          public List setQuotaUser(java.lang.String quotaUser) {
            return (List) super.setQuotaUser(quotaUser);
          }

          @Override
          public List setUserIp(java.lang.String userIp) {
            return (List) super.setUserIp(userIp);
          }

          /** Account to which the ad client belongs. */
          @com.google.api.client.util.Key
          private java.lang.String accountId;

          /** Account to which the ad client belongs.
           */
          public java.lang.String getAccountId() {
            return accountId;
          }

          /** Account to which the ad client belongs. */
          public List setAccountId(java.lang.String accountId) {
            this.accountId = accountId;
            return this;
          }

          /** Ad client which contains the custom channel. */
          @com.google.api.client.util.Key
          private java.lang.String adClientId;

          /** Ad client which contains the custom channel.
           */
          public java.lang.String getAdClientId() {
            return adClientId;
          }

          /** Ad client which contains the custom channel. */
          public List setAdClientId(java.lang.String adClientId) {
            this.adClientId = adClientId;
            return this;
          }

          /** Custom channel for which to list ad units. */
          @com.google.api.client.util.Key
          private java.lang.String customChannelId;

          /** Custom channel for which to list ad units.
           */
          public java.lang.String getCustomChannelId() {
            return customChannelId;
          }

          /** Custom channel for which to list ad units. */
          public List setCustomChannelId(java.lang.String customChannelId) {
            this.customChannelId = customChannelId;
            return this;
          }

          /** Whether to include inactive ad units. Default: true. */
          @com.google.api.client.util.Key
          private java.lang.Boolean includeInactive;

          /** Whether to include inactive ad units. Default: true.
           */
          public java.lang.Boolean getIncludeInactive() {
            return includeInactive;
          }

          /** Whether to include inactive ad units. Default: true. */
          public List setIncludeInactive(java.lang.Boolean includeInactive) {
            this.includeInactive = includeInactive;
            return this;
          }

          /** The maximum number of ad units to include in the response, used for paging. */
          @com.google.api.client.util.Key
          private java.lang.Integer maxResults;

          /** The maximum number of ad units to include in the response, used for paging.

         [minimum: 0] [maximum: 10000]
           */
          public java.lang.Integer getMaxResults() {
            return maxResults;
          }

          /** The maximum number of ad units to include in the response, used for paging. */
          public List setMaxResults(java.lang.Integer maxResults) {
            this.maxResults = maxResults;
            return this;
          }

          /**
           * A continuation token, used to page through ad units. To retrieve the next page, set
           * this parameter to the value of "nextPageToken" from the previous response.
           */
          @com.google.api.client.util.Key
          private java.lang.String pageToken;

          /** A continuation token, used to page through ad units. To retrieve the next page, set this parameter
         to the value of "nextPageToken" from the previous response.
           */
          public java.lang.String getPageToken() {
            return pageToken;
          }

          /**
           * A continuation token, used to page through ad units. To retrieve the next page, set
           * this parameter to the value of "nextPageToken" from the previous response.
           */
          public List setPageToken(java.lang.String pageToken) {
            this.pageToken = pageToken;
            return this;
          }

          @Override
          public List set(String parameterName, Object value) {
            return (List) super.set(parameterName, value);
          }
        }

      }
    }
    /**
     * An accessor for creating requests from the Reports collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Reports.List request = adsense.reports().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Reports reports() {
      return new Reports();
    }

    /**
     * The "reports" collection of methods.
     */
    public class Reports {

      /**
       * Generate an AdSense report based on the report request sent in the query parameters. Returns the
       * result as JSON; to retrieve output in CSV format specify "alt=csv" as a query parameter.
       *
       * Create a request for the method "reports.generate".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Generate#execute()} method to invoke the remote operation.
       *
       * @param accountId Account upon which to report.
       * @param startDate Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
       * @param endDate End of the date range to report on in "YYYY-MM-DD" format, inclusive.
       * @return the request
       */
      public Generate generate(java.lang.String accountId, java.lang.String startDate, java.lang.String endDate) throws java.io.IOException {
        Generate result = new Generate(accountId, startDate, endDate);
        initialize(result);
        return result;
      }

      public class Generate extends AdSenseRequest<com.google.api.services.adsense.model.AdsenseReportsGenerateResponse> {

        private static final String REST_PATH = "accounts/{accountId}/reports";

        private final java.util.regex.Pattern STARTDATE_PATTERN =
            java.util.regex.Pattern.compile("\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");

        private final java.util.regex.Pattern ENDDATE_PATTERN =
            java.util.regex.Pattern.compile("\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");

        private final java.util.regex.Pattern SORT_PATTERN =
            java.util.regex.Pattern.compile("(\\+|-)?[a-zA-Z_]+");

        private final java.util.regex.Pattern LOCALE_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z_]+");

        private final java.util.regex.Pattern METRIC_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z_]+");

        private final java.util.regex.Pattern FILTER_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z_]+(==|=@).+");

        private final java.util.regex.Pattern CURRENCY_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z]+");

        private final java.util.regex.Pattern DIMENSION_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z_]+");

        /**
         * Generate an AdSense report based on the report request sent in the query parameters. Returns
         * the result as JSON; to retrieve output in CSV format specify "alt=csv" as a query parameter.
         *
         * Create a request for the method "reports.generate".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link Generate#execute()} method to invoke the remote operation. <p>
         * {@link
         * Generate#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account upon which to report.
         * @param startDate Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
         * @param endDate End of the date range to report on in "YYYY-MM-DD" format, inclusive.
         * @since 1.13
         */
        protected Generate(java.lang.String accountId, java.lang.String startDate, java.lang.String endDate) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdsenseReportsGenerateResponse.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.startDate = com.google.api.client.util.Preconditions.checkNotNull(startDate, "Required parameter startDate must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(STARTDATE_PATTERN.matcher(startDate).matches(),
                "Parameter startDate must conform to the pattern " +
                "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
          }
          this.endDate = com.google.api.client.util.Preconditions.checkNotNull(endDate, "Required parameter endDate must be specified.");
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(ENDDATE_PATTERN.matcher(endDate).matches(),
                "Parameter endDate must conform to the pattern " +
                "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
          }
          initializeMediaDownload();
        }

        @Override
        public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
          super.executeMediaAndDownloadTo(outputStream);
        }

        @Override
        public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
          return super.executeMediaAsInputStream();
        }

        @Override
        public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
          return super.executeMedia();
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Generate setAlt(java.lang.String alt) {
          return (Generate) super.setAlt(alt);
        }

        @Override
        public Generate setFields(java.lang.String fields) {
          return (Generate) super.setFields(fields);
        }

        @Override
        public Generate setKey(java.lang.String key) {
          return (Generate) super.setKey(key);
        }

        @Override
        public Generate setOauthToken(java.lang.String oauthToken) {
          return (Generate) super.setOauthToken(oauthToken);
        }

        @Override
        public Generate setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Generate) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Generate setQuotaUser(java.lang.String quotaUser) {
          return (Generate) super.setQuotaUser(quotaUser);
        }

        @Override
        public Generate setUserIp(java.lang.String userIp) {
          return (Generate) super.setUserIp(userIp);
        }

        /** Account upon which to report. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account upon which to report.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account upon which to report. */
        public Generate setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive. */
        @com.google.api.client.util.Key
        private java.lang.String startDate;

        /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
         */
        public java.lang.String getStartDate() {
          return startDate;
        }

        /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive. */
        public Generate setStartDate(java.lang.String startDate) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(STARTDATE_PATTERN.matcher(startDate).matches(),
                "Parameter startDate must conform to the pattern " +
                "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
          }
          this.startDate = startDate;
          return this;
        }

        /** End of the date range to report on in "YYYY-MM-DD" format, inclusive. */
        @com.google.api.client.util.Key
        private java.lang.String endDate;

        /** End of the date range to report on in "YYYY-MM-DD" format, inclusive.
         */
        public java.lang.String getEndDate() {
          return endDate;
        }

        /** End of the date range to report on in "YYYY-MM-DD" format, inclusive. */
        public Generate setEndDate(java.lang.String endDate) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(ENDDATE_PATTERN.matcher(endDate).matches(),
                "Parameter endDate must conform to the pattern " +
                "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
          }
          this.endDate = endDate;
          return this;
        }

        /**
         * The name of a dimension or metric to sort the resulting report on, optionally prefixed
         * with "+" to sort ascending or "-" to sort descending. If no prefix is specified, the
         * column is sorted ascending.
         */
        @com.google.api.client.util.Key
        private java.util.List<java.lang.String> sort;

        /** The name of a dimension or metric to sort the resulting report on, optionally prefixed with "+" to
       sort ascending or "-" to sort descending. If no prefix is specified, the column is sorted
       ascending.
         */
        public java.util.List<java.lang.String> getSort() {
          return sort;
        }

        /**
         * The name of a dimension or metric to sort the resulting report on, optionally prefixed
         * with "+" to sort ascending or "-" to sort descending. If no prefix is specified, the
         * column is sorted ascending.
         */
        public Generate setSort(java.util.List<java.lang.String> sort) {
          if (!getSuppressPatternChecks()) {
            for (String sortElem : sort) {
              com.google.api.client.util.Preconditions.checkArgument(SORT_PATTERN.matcher(sortElem).matches(),
                  "Parameter sort elements must conform to the pattern " +
                  "(\\+|-)?[a-zA-Z_]+");
            }
          }
          this.sort = sort;
          return this;
        }

        /**
         * Optional locale to use for translating report output to a local language. Defaults to
         * "en_US" if not specified.
         */
        @com.google.api.client.util.Key
        private java.lang.String locale;

        /** Optional locale to use for translating report output to a local language. Defaults to "en_US" if
       not specified.
         */
        public java.lang.String getLocale() {
          return locale;
        }

        /**
         * Optional locale to use for translating report output to a local language. Defaults to
         * "en_US" if not specified.
         */
        public Generate setLocale(java.lang.String locale) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(LOCALE_PATTERN.matcher(locale).matches(),
                "Parameter locale must conform to the pattern " +
                "[a-zA-Z_]+");
          }
          this.locale = locale;
          return this;
        }

        /** Numeric columns to include in the report. */
        @com.google.api.client.util.Key
        private java.util.List<java.lang.String> metric;

        /** Numeric columns to include in the report.
         */
        public java.util.List<java.lang.String> getMetric() {
          return metric;
        }

        /** Numeric columns to include in the report. */
        public Generate setMetric(java.util.List<java.lang.String> metric) {
          if (!getSuppressPatternChecks()) {
            for (String metricElem : metric) {
              com.google.api.client.util.Preconditions.checkArgument(METRIC_PATTERN.matcher(metricElem).matches(),
                  "Parameter metric elements must conform to the pattern " +
                  "[a-zA-Z_]+");
            }
          }
          this.metric = metric;
          return this;
        }

        /** The maximum number of rows of report data to return. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of rows of report data to return.

       [minimum: 0] [maximum: 50000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of rows of report data to return. */
        public Generate setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** Filters to be run on the report. */
        @com.google.api.client.util.Key
        private java.util.List<java.lang.String> filter;

        /** Filters to be run on the report.
         */
        public java.util.List<java.lang.String> getFilter() {
          return filter;
        }

        /** Filters to be run on the report. */
        public Generate setFilter(java.util.List<java.lang.String> filter) {
          if (!getSuppressPatternChecks()) {
            for (String filterElem : filter) {
              com.google.api.client.util.Preconditions.checkArgument(FILTER_PATTERN.matcher(filterElem).matches(),
                  "Parameter filter elements must conform to the pattern " +
                  "[a-zA-Z_]+(==|=@).+");
            }
          }
          this.filter = filter;
          return this;
        }

        /**
         * Optional currency to use when reporting on monetary metrics. Defaults to the account's
         * currency if not set.
         */
        @com.google.api.client.util.Key
        private java.lang.String currency;

        /** Optional currency to use when reporting on monetary metrics. Defaults to the account's currency if
       not set.
         */
        public java.lang.String getCurrency() {
          return currency;
        }

        /**
         * Optional currency to use when reporting on monetary metrics. Defaults to the account's
         * currency if not set.
         */
        public Generate setCurrency(java.lang.String currency) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(CURRENCY_PATTERN.matcher(currency).matches(),
                "Parameter currency must conform to the pattern " +
                "[a-zA-Z]+");
          }
          this.currency = currency;
          return this;
        }

        /** Index of the first row of report data to return. */
        @com.google.api.client.util.Key
        private java.lang.Integer startIndex;

        /** Index of the first row of report data to return.

       [minimum: 0] [maximum: 5000]
         */
        public java.lang.Integer getStartIndex() {
          return startIndex;
        }

        /** Index of the first row of report data to return. */
        public Generate setStartIndex(java.lang.Integer startIndex) {
          this.startIndex = startIndex;
          return this;
        }

        /**
         * Whether the report should be generated in the AdSense account's local timezone. If false
         * default PST/PDT timezone will be used.
         */
        @com.google.api.client.util.Key
        private java.lang.Boolean useTimezoneReporting;

        /** Whether the report should be generated in the AdSense account's local timezone. If false default
       PST/PDT timezone will be used.
         */
        public java.lang.Boolean getUseTimezoneReporting() {
          return useTimezoneReporting;
        }

        /**
         * Whether the report should be generated in the AdSense account's local timezone. If false
         * default PST/PDT timezone will be used.
         */
        public Generate setUseTimezoneReporting(java.lang.Boolean useTimezoneReporting) {
          this.useTimezoneReporting = useTimezoneReporting;
          return this;
        }

        /** Dimensions to base the report on. */
        @com.google.api.client.util.Key
        private java.util.List<java.lang.String> dimension;

        /** Dimensions to base the report on.
         */
        public java.util.List<java.lang.String> getDimension() {
          return dimension;
        }

        /** Dimensions to base the report on. */
        public Generate setDimension(java.util.List<java.lang.String> dimension) {
          if (!getSuppressPatternChecks()) {
            for (String dimensionElem : dimension) {
              com.google.api.client.util.Preconditions.checkArgument(DIMENSION_PATTERN.matcher(dimensionElem).matches(),
                  "Parameter dimension elements must conform to the pattern " +
                  "[a-zA-Z_]+");
            }
          }
          this.dimension = dimension;
          return this;
        }

        @Override
        public Generate set(String parameterName, Object value) {
          return (Generate) super.set(parameterName, value);
        }
      }

      /**
       * An accessor for creating requests from the Saved collection.
       *
       * <p>The typical use is:</p>
       * <pre>
       *   {@code AdSense adsense = new AdSense(...);}
       *   {@code AdSense.Saved.List request = adsense.saved().list(parameters ...)}
       * </pre>
       *
       * @return the resource collection
       */
      public Saved saved() {
        return new Saved();
      }

      /**
       * The "saved" collection of methods.
       */
      public class Saved {

        /**
         * Generate an AdSense report based on the saved report ID sent in the query parameters.
         *
         * Create a request for the method "saved.generate".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link Generate#execute()} method to invoke the remote operation.
         *
         * @param accountId Account to which the saved reports belong.
         * @param savedReportId The saved report to retrieve.
         * @return the request
         */
        public Generate generate(java.lang.String accountId, java.lang.String savedReportId) throws java.io.IOException {
          Generate result = new Generate(accountId, savedReportId);
          initialize(result);
          return result;
        }

        public class Generate extends AdSenseRequest<com.google.api.services.adsense.model.AdsenseReportsGenerateResponse> {

          private static final String REST_PATH = "accounts/{accountId}/reports/{savedReportId}";

          private final java.util.regex.Pattern LOCALE_PATTERN =
              java.util.regex.Pattern.compile("[a-zA-Z_]+");

          /**
           * Generate an AdSense report based on the saved report ID sent in the query parameters.
           *
           * Create a request for the method "saved.generate".
           *
           * This request holds the parameters needed by the the adsense server.  After setting any optional
           * parameters, call the {@link Generate#execute()} method to invoke the remote operation. <p>
           * {@link
           * Generate#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
           * must be called to initialize this instance immediately after invoking the constructor. </p>
           *
           * @param accountId Account to which the saved reports belong.
           * @param savedReportId The saved report to retrieve.
           * @since 1.13
           */
          protected Generate(java.lang.String accountId, java.lang.String savedReportId) {
            super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdsenseReportsGenerateResponse.class);
            this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
            this.savedReportId = com.google.api.client.util.Preconditions.checkNotNull(savedReportId, "Required parameter savedReportId must be specified.");
          }

          @Override
          public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
            return super.executeUsingHead();
          }

          @Override
          public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
            return super.buildHttpRequestUsingHead();
          }

          @Override
          public Generate setAlt(java.lang.String alt) {
            return (Generate) super.setAlt(alt);
          }

          @Override
          public Generate setFields(java.lang.String fields) {
            return (Generate) super.setFields(fields);
          }

          @Override
          public Generate setKey(java.lang.String key) {
            return (Generate) super.setKey(key);
          }

          @Override
          public Generate setOauthToken(java.lang.String oauthToken) {
            return (Generate) super.setOauthToken(oauthToken);
          }

          @Override
          public Generate setPrettyPrint(java.lang.Boolean prettyPrint) {
            return (Generate) super.setPrettyPrint(prettyPrint);
          }

          @Override
          public Generate setQuotaUser(java.lang.String quotaUser) {
            return (Generate) super.setQuotaUser(quotaUser);
          }

          @Override
          public Generate setUserIp(java.lang.String userIp) {
            return (Generate) super.setUserIp(userIp);
          }

          /** Account to which the saved reports belong. */
          @com.google.api.client.util.Key
          private java.lang.String accountId;

          /** Account to which the saved reports belong.
           */
          public java.lang.String getAccountId() {
            return accountId;
          }

          /** Account to which the saved reports belong. */
          public Generate setAccountId(java.lang.String accountId) {
            this.accountId = accountId;
            return this;
          }

          /** The saved report to retrieve. */
          @com.google.api.client.util.Key
          private java.lang.String savedReportId;

          /** The saved report to retrieve.
           */
          public java.lang.String getSavedReportId() {
            return savedReportId;
          }

          /** The saved report to retrieve. */
          public Generate setSavedReportId(java.lang.String savedReportId) {
            this.savedReportId = savedReportId;
            return this;
          }

          /**
           * Optional locale to use for translating report output to a local language. Defaults to
           * "en_US" if not specified.
           */
          @com.google.api.client.util.Key
          private java.lang.String locale;

          /** Optional locale to use for translating report output to a local language. Defaults to "en_US" if
         not specified.
           */
          public java.lang.String getLocale() {
            return locale;
          }

          /**
           * Optional locale to use for translating report output to a local language. Defaults to
           * "en_US" if not specified.
           */
          public Generate setLocale(java.lang.String locale) {
            if (!getSuppressPatternChecks()) {
              com.google.api.client.util.Preconditions.checkArgument(LOCALE_PATTERN.matcher(locale).matches(),
                  "Parameter locale must conform to the pattern " +
                  "[a-zA-Z_]+");
            }
            this.locale = locale;
            return this;
          }

          /** Index of the first row of report data to return. */
          @com.google.api.client.util.Key
          private java.lang.Integer startIndex;

          /** Index of the first row of report data to return.

         [minimum: 0] [maximum: 5000]
           */
          public java.lang.Integer getStartIndex() {
            return startIndex;
          }

          /** Index of the first row of report data to return. */
          public Generate setStartIndex(java.lang.Integer startIndex) {
            this.startIndex = startIndex;
            return this;
          }

          /** The maximum number of rows of report data to return. */
          @com.google.api.client.util.Key
          private java.lang.Integer maxResults;

          /** The maximum number of rows of report data to return.

         [minimum: 0] [maximum: 50000]
           */
          public java.lang.Integer getMaxResults() {
            return maxResults;
          }

          /** The maximum number of rows of report data to return. */
          public Generate setMaxResults(java.lang.Integer maxResults) {
            this.maxResults = maxResults;
            return this;
          }

          @Override
          public Generate set(String parameterName, Object value) {
            return (Generate) super.set(parameterName, value);
          }
        }
        /**
         * List all saved reports in the specified AdSense account.
         *
         * Create a request for the method "saved.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation.
         *
         * @param accountId Account to which the saved reports belong.
         * @return the request
         */
        public List list(java.lang.String accountId) throws java.io.IOException {
          List result = new List(accountId);
          initialize(result);
          return result;
        }

        public class List extends AdSenseRequest<com.google.api.services.adsense.model.SavedReports> {

          private static final String REST_PATH = "accounts/{accountId}/reports/saved";

          /**
           * List all saved reports in the specified AdSense account.
           *
           * Create a request for the method "saved.list".
           *
           * This request holds the parameters needed by the the adsense server.  After setting any optional
           * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
           * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
           * called to initialize this instance immediately after invoking the constructor. </p>
           *
           * @param accountId Account to which the saved reports belong.
           * @since 1.13
           */
          protected List(java.lang.String accountId) {
            super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.SavedReports.class);
            this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          }

          @Override
          public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
            return super.executeUsingHead();
          }

          @Override
          public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
            return super.buildHttpRequestUsingHead();
          }

          @Override
          public List setAlt(java.lang.String alt) {
            return (List) super.setAlt(alt);
          }

          @Override
          public List setFields(java.lang.String fields) {
            return (List) super.setFields(fields);
          }

          @Override
          public List setKey(java.lang.String key) {
            return (List) super.setKey(key);
          }

          @Override
          public List setOauthToken(java.lang.String oauthToken) {
            return (List) super.setOauthToken(oauthToken);
          }

          @Override
          public List setPrettyPrint(java.lang.Boolean prettyPrint) {
            return (List) super.setPrettyPrint(prettyPrint);
          }

          @Override
          public List setQuotaUser(java.lang.String quotaUser) {
            return (List) super.setQuotaUser(quotaUser);
          }

          @Override
          public List setUserIp(java.lang.String userIp) {
            return (List) super.setUserIp(userIp);
          }

          /** Account to which the saved reports belong. */
          @com.google.api.client.util.Key
          private java.lang.String accountId;

          /** Account to which the saved reports belong.
           */
          public java.lang.String getAccountId() {
            return accountId;
          }

          /** Account to which the saved reports belong. */
          public List setAccountId(java.lang.String accountId) {
            this.accountId = accountId;
            return this;
          }

          /**
           * A continuation token, used to page through saved reports. To retrieve the next page,
           * set this parameter to the value of "nextPageToken" from the previous response.
           */
          @com.google.api.client.util.Key
          private java.lang.String pageToken;

          /** A continuation token, used to page through saved reports. To retrieve the next page, set this
         parameter to the value of "nextPageToken" from the previous response.
           */
          public java.lang.String getPageToken() {
            return pageToken;
          }

          /**
           * A continuation token, used to page through saved reports. To retrieve the next page,
           * set this parameter to the value of "nextPageToken" from the previous response.
           */
          public List setPageToken(java.lang.String pageToken) {
            this.pageToken = pageToken;
            return this;
          }

          /** The maximum number of saved reports to include in the response, used for paging. */
          @com.google.api.client.util.Key
          private java.lang.Integer maxResults;

          /** The maximum number of saved reports to include in the response, used for paging.

         [minimum: 0] [maximum: 100]
           */
          public java.lang.Integer getMaxResults() {
            return maxResults;
          }

          /** The maximum number of saved reports to include in the response, used for paging. */
          public List setMaxResults(java.lang.Integer maxResults) {
            this.maxResults = maxResults;
            return this;
          }

          @Override
          public List set(String parameterName, Object value) {
            return (List) super.set(parameterName, value);
          }
        }

      }
    }
    /**
     * An accessor for creating requests from the Savedadstyles collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Savedadstyles.List request = adsense.savedadstyles().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Savedadstyles savedadstyles() {
      return new Savedadstyles();
    }

    /**
     * The "savedadstyles" collection of methods.
     */
    public class Savedadstyles {

      /**
       * List a specific saved ad style for the specified account.
       *
       * Create a request for the method "savedadstyles.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param accountId Account for which to get the saved ad style.
       * @param savedAdStyleId Saved ad style to retrieve.
       * @return the request
       */
      public Get get(java.lang.String accountId, java.lang.String savedAdStyleId) throws java.io.IOException {
        Get result = new Get(accountId, savedAdStyleId);
        initialize(result);
        return result;
      }

      public class Get extends AdSenseRequest<com.google.api.services.adsense.model.SavedAdStyle> {

        private static final String REST_PATH = "accounts/{accountId}/savedadstyles/{savedAdStyleId}";

        /**
         * List a specific saved ad style for the specified account.
         *
         * Create a request for the method "savedadstyles.get".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
         * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account for which to get the saved ad style.
         * @param savedAdStyleId Saved ad style to retrieve.
         * @since 1.13
         */
        protected Get(java.lang.String accountId, java.lang.String savedAdStyleId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.SavedAdStyle.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.savedAdStyleId = com.google.api.client.util.Preconditions.checkNotNull(savedAdStyleId, "Required parameter savedAdStyleId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(java.lang.String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** Account for which to get the saved ad style. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account for which to get the saved ad style.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account for which to get the saved ad style. */
        public Get setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Saved ad style to retrieve. */
        @com.google.api.client.util.Key
        private java.lang.String savedAdStyleId;

        /** Saved ad style to retrieve.
         */
        public java.lang.String getSavedAdStyleId() {
          return savedAdStyleId;
        }

        /** Saved ad style to retrieve. */
        public Get setSavedAdStyleId(java.lang.String savedAdStyleId) {
          this.savedAdStyleId = savedAdStyleId;
          return this;
        }

        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * List all saved ad styles in the specified account.
       *
       * Create a request for the method "savedadstyles.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param accountId Account for which to list saved ad styles.
       * @return the request
       */
      public List list(java.lang.String accountId) throws java.io.IOException {
        List result = new List(accountId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.SavedAdStyles> {

        private static final String REST_PATH = "accounts/{accountId}/savedadstyles";

        /**
         * List all saved ad styles in the specified account.
         *
         * Create a request for the method "savedadstyles.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account for which to list saved ad styles.
         * @since 1.13
         */
        protected List(java.lang.String accountId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.SavedAdStyles.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Account for which to list saved ad styles. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account for which to list saved ad styles.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account for which to list saved ad styles. */
        public List setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /**
         * A continuation token, used to page through saved ad styles. To retrieve the next page,
         * set this parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through saved ad styles. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through saved ad styles. To retrieve the next page,
         * set this parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of saved ad styles to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of saved ad styles to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of saved ad styles to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the Urlchannels collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Urlchannels.List request = adsense.urlchannels().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Urlchannels urlchannels() {
      return new Urlchannels();
    }

    /**
     * The "urlchannels" collection of methods.
     */
    public class Urlchannels {

      /**
       * List all URL channels in the specified ad client for the specified account.
       *
       * Create a request for the method "urlchannels.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param accountId Account to which the ad client belongs.
       * @param adClientId Ad client for which to list URL channels.
       * @return the request
       */
      public List list(java.lang.String accountId, java.lang.String adClientId) throws java.io.IOException {
        List result = new List(accountId, adClientId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.UrlChannels> {

        private static final String REST_PATH = "accounts/{accountId}/adclients/{adClientId}/urlchannels";

        /**
         * List all URL channels in the specified ad client for the specified account.
         *
         * Create a request for the method "urlchannels.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param accountId Account to which the ad client belongs.
         * @param adClientId Ad client for which to list URL channels.
         * @since 1.13
         */
        protected List(java.lang.String accountId, java.lang.String adClientId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.UrlChannels.class);
          this.accountId = com.google.api.client.util.Preconditions.checkNotNull(accountId, "Required parameter accountId must be specified.");
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Account to which the ad client belongs. */
        @com.google.api.client.util.Key
        private java.lang.String accountId;

        /** Account to which the ad client belongs.
         */
        public java.lang.String getAccountId() {
          return accountId;
        }

        /** Account to which the ad client belongs. */
        public List setAccountId(java.lang.String accountId) {
          this.accountId = accountId;
          return this;
        }

        /** Ad client for which to list URL channels. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client for which to list URL channels.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client for which to list URL channels. */
        public List setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /**
         * A continuation token, used to page through URL channels. To retrieve the next page, set
         * this parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through URL channels. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through URL channels. To retrieve the next page, set
         * this parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of URL channels to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of URL channels to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of URL channels to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the Adclients collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Adclients.List request = adsense.adclients().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Adclients adclients() {
    return new Adclients();
  }

  /**
   * The "adclients" collection of methods.
   */
  public class Adclients {

    /**
     * List all ad clients in this AdSense account.
     *
     * Create a request for the method "adclients.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.AdClients> {

      private static final String REST_PATH = "adclients";

      /**
       * List all ad clients in this AdSense account.
       *
       * Create a request for the method "adclients.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdClients.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
       * A continuation token, used to page through ad clients. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** A continuation token, used to page through ad clients. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * A continuation token, used to page through ad clients. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of ad clients to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of ad clients to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of ad clients to include in the response, used for paging. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Adunits collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Adunits.List request = adsense.adunits().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Adunits adunits() {
    return new Adunits();
  }

  /**
   * The "adunits" collection of methods.
   */
  public class Adunits {

    /**
     * Gets the specified ad unit in the specified ad client.
     *
     * Create a request for the method "adunits.get".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to get the ad unit.
     * @param adUnitId Ad unit to retrieve.
     * @return the request
     */
    public Get get(java.lang.String adClientId, java.lang.String adUnitId) throws java.io.IOException {
      Get result = new Get(adClientId, adUnitId);
      initialize(result);
      return result;
    }

    public class Get extends AdSenseRequest<com.google.api.services.adsense.model.AdUnit> {

      private static final String REST_PATH = "adclients/{adClientId}/adunits/{adUnitId}";

      /**
       * Gets the specified ad unit in the specified ad client.
       *
       * Create a request for the method "adunits.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to get the ad unit.
       * @param adUnitId Ad unit to retrieve.
       * @since 1.13
       */
      protected Get(java.lang.String adClientId, java.lang.String adUnitId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdUnit.class);
        this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        this.adUnitId = com.google.api.client.util.Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Ad client for which to get the ad unit. */
      @com.google.api.client.util.Key
      private java.lang.String adClientId;

      /** Ad client for which to get the ad unit.
       */
      public java.lang.String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to get the ad unit. */
      public Get setAdClientId(java.lang.String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Ad unit to retrieve. */
      @com.google.api.client.util.Key
      private java.lang.String adUnitId;

      /** Ad unit to retrieve.
       */
      public java.lang.String getAdUnitId() {
        return adUnitId;
      }

      /** Ad unit to retrieve. */
      public Get setAdUnitId(java.lang.String adUnitId) {
        this.adUnitId = adUnitId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Get ad code for the specified ad unit.
     *
     * Create a request for the method "adunits.getAdCode".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link GetAdCode#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client with contains the ad unit.
     * @param adUnitId Ad unit to get the code for.
     * @return the request
     */
    public GetAdCode getAdCode(java.lang.String adClientId, java.lang.String adUnitId) throws java.io.IOException {
      GetAdCode result = new GetAdCode(adClientId, adUnitId);
      initialize(result);
      return result;
    }

    public class GetAdCode extends AdSenseRequest<com.google.api.services.adsense.model.AdCode> {

      private static final String REST_PATH = "adclients/{adClientId}/adunits/{adUnitId}/adcode";

      /**
       * Get ad code for the specified ad unit.
       *
       * Create a request for the method "adunits.getAdCode".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link GetAdCode#execute()} method to invoke the remote operation. <p>
       * {@link
       * GetAdCode#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client with contains the ad unit.
       * @param adUnitId Ad unit to get the code for.
       * @since 1.13
       */
      protected GetAdCode(java.lang.String adClientId, java.lang.String adUnitId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdCode.class);
        this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        this.adUnitId = com.google.api.client.util.Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public GetAdCode setAlt(java.lang.String alt) {
        return (GetAdCode) super.setAlt(alt);
      }

      @Override
      public GetAdCode setFields(java.lang.String fields) {
        return (GetAdCode) super.setFields(fields);
      }

      @Override
      public GetAdCode setKey(java.lang.String key) {
        return (GetAdCode) super.setKey(key);
      }

      @Override
      public GetAdCode setOauthToken(java.lang.String oauthToken) {
        return (GetAdCode) super.setOauthToken(oauthToken);
      }

      @Override
      public GetAdCode setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (GetAdCode) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public GetAdCode setQuotaUser(java.lang.String quotaUser) {
        return (GetAdCode) super.setQuotaUser(quotaUser);
      }

      @Override
      public GetAdCode setUserIp(java.lang.String userIp) {
        return (GetAdCode) super.setUserIp(userIp);
      }

      /** Ad client with contains the ad unit. */
      @com.google.api.client.util.Key
      private java.lang.String adClientId;

      /** Ad client with contains the ad unit.
       */
      public java.lang.String getAdClientId() {
        return adClientId;
      }

      /** Ad client with contains the ad unit. */
      public GetAdCode setAdClientId(java.lang.String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Ad unit to get the code for. */
      @com.google.api.client.util.Key
      private java.lang.String adUnitId;

      /** Ad unit to get the code for.
       */
      public java.lang.String getAdUnitId() {
        return adUnitId;
      }

      /** Ad unit to get the code for. */
      public GetAdCode setAdUnitId(java.lang.String adUnitId) {
        this.adUnitId = adUnitId;
        return this;
      }

      @Override
      public GetAdCode set(String parameterName, Object value) {
        return (GetAdCode) super.set(parameterName, value);
      }
    }
    /**
     * List all ad units in the specified ad client for this AdSense account.
     *
     * Create a request for the method "adunits.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to list ad units.
     * @return the request
     */
    public List list(java.lang.String adClientId) throws java.io.IOException {
      List result = new List(adClientId);
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.AdUnits> {

      private static final String REST_PATH = "adclients/{adClientId}/adunits";

      /**
       * List all ad units in the specified ad client for this AdSense account.
       *
       * Create a request for the method "adunits.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to list ad units.
       * @since 1.13
       */
      protected List(java.lang.String adClientId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdUnits.class);
        this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Ad client for which to list ad units. */
      @com.google.api.client.util.Key
      private java.lang.String adClientId;

      /** Ad client for which to list ad units.
       */
      public java.lang.String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to list ad units. */
      public List setAdClientId(java.lang.String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Whether to include inactive ad units. Default: true. */
      @com.google.api.client.util.Key
      private java.lang.Boolean includeInactive;

      /** Whether to include inactive ad units. Default: true.
       */
      public java.lang.Boolean getIncludeInactive() {
        return includeInactive;
      }

      /** Whether to include inactive ad units. Default: true. */
      public List setIncludeInactive(java.lang.Boolean includeInactive) {
        this.includeInactive = includeInactive;
        return this;
      }

      /**
       * A continuation token, used to page through ad units. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** A continuation token, used to page through ad units. To retrieve the next page, set this parameter
     to the value of "nextPageToken" from the previous response.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * A continuation token, used to page through ad units. To retrieve the next page, set this
       * parameter to the value of "nextPageToken" from the previous response.
       */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of ad units to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of ad units to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of ad units to include in the response, used for paging. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the Customchannels collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Customchannels.List request = adsense.customchannels().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Customchannels customchannels() {
      return new Customchannels();
    }

    /**
     * The "customchannels" collection of methods.
     */
    public class Customchannels {

      /**
       * List all custom channels which the specified ad unit belongs to.
       *
       * Create a request for the method "customchannels.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param adClientId Ad client which contains the ad unit.
       * @param adUnitId Ad unit for which to list custom channels.
       * @return the request
       */
      public List list(java.lang.String adClientId, java.lang.String adUnitId) throws java.io.IOException {
        List result = new List(adClientId, adUnitId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.CustomChannels> {

        private static final String REST_PATH = "adclients/{adClientId}/adunits/{adUnitId}/customchannels";

        /**
         * List all custom channels which the specified ad unit belongs to.
         *
         * Create a request for the method "customchannels.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param adClientId Ad client which contains the ad unit.
         * @param adUnitId Ad unit for which to list custom channels.
         * @since 1.13
         */
        protected List(java.lang.String adClientId, java.lang.String adUnitId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.CustomChannels.class);
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.adUnitId = com.google.api.client.util.Preconditions.checkNotNull(adUnitId, "Required parameter adUnitId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Ad client which contains the ad unit. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client which contains the ad unit.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client which contains the ad unit. */
        public List setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Ad unit for which to list custom channels. */
        @com.google.api.client.util.Key
        private java.lang.String adUnitId;

        /** Ad unit for which to list custom channels.
         */
        public java.lang.String getAdUnitId() {
          return adUnitId;
        }

        /** Ad unit for which to list custom channels. */
        public List setAdUnitId(java.lang.String adUnitId) {
          this.adUnitId = adUnitId;
          return this;
        }

        /**
         * A continuation token, used to page through custom channels. To retrieve the next page,
         * set this parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through custom channels. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through custom channels. To retrieve the next page,
         * set this parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of custom channels to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of custom channels to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of custom channels to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the Alerts collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Alerts.List request = adsense.alerts().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Alerts alerts() {
    return new Alerts();
  }

  /**
   * The "alerts" collection of methods.
   */
  public class Alerts {

    /**
     * List the alerts for this AdSense account.
     *
     * Create a request for the method "alerts.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.Alerts> {

      private static final String REST_PATH = "alerts";

      /**
       * List the alerts for this AdSense account.
       *
       * Create a request for the method "alerts.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.Alerts.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
       * The locale to use for translating alert messages. The account locale will be used if this
       * is not supplied. The AdSense default (English) will be used if the supplied locale is
       * invalid or unsupported.
       */
      @com.google.api.client.util.Key
      private java.lang.String locale;

      /** The locale to use for translating alert messages. The account locale will be used if this is not
     supplied. The AdSense default (English) will be used if the supplied locale is invalid or
     unsupported.
       */
      public java.lang.String getLocale() {
        return locale;
      }

      /**
       * The locale to use for translating alert messages. The account locale will be used if this
       * is not supplied. The AdSense default (English) will be used if the supplied locale is
       * invalid or unsupported.
       */
      public List setLocale(java.lang.String locale) {
        this.locale = locale;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Customchannels collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Customchannels.List request = adsense.customchannels().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Customchannels customchannels() {
    return new Customchannels();
  }

  /**
   * The "customchannels" collection of methods.
   */
  public class Customchannels {

    /**
     * Get the specified custom channel from the specified ad client.
     *
     * Create a request for the method "customchannels.get".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client which contains the custom channel.
     * @param customChannelId Custom channel to retrieve.
     * @return the request
     */
    public Get get(java.lang.String adClientId, java.lang.String customChannelId) throws java.io.IOException {
      Get result = new Get(adClientId, customChannelId);
      initialize(result);
      return result;
    }

    public class Get extends AdSenseRequest<com.google.api.services.adsense.model.CustomChannel> {

      private static final String REST_PATH = "adclients/{adClientId}/customchannels/{customChannelId}";

      /**
       * Get the specified custom channel from the specified ad client.
       *
       * Create a request for the method "customchannels.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client which contains the custom channel.
       * @param customChannelId Custom channel to retrieve.
       * @since 1.13
       */
      protected Get(java.lang.String adClientId, java.lang.String customChannelId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.CustomChannel.class);
        this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
        this.customChannelId = com.google.api.client.util.Preconditions.checkNotNull(customChannelId, "Required parameter customChannelId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Ad client which contains the custom channel. */
      @com.google.api.client.util.Key
      private java.lang.String adClientId;

      /** Ad client which contains the custom channel.
       */
      public java.lang.String getAdClientId() {
        return adClientId;
      }

      /** Ad client which contains the custom channel. */
      public Get setAdClientId(java.lang.String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /** Custom channel to retrieve. */
      @com.google.api.client.util.Key
      private java.lang.String customChannelId;

      /** Custom channel to retrieve.
       */
      public java.lang.String getCustomChannelId() {
        return customChannelId;
      }

      /** Custom channel to retrieve. */
      public Get setCustomChannelId(java.lang.String customChannelId) {
        this.customChannelId = customChannelId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * List all custom channels in the specified ad client for this AdSense account.
     *
     * Create a request for the method "customchannels.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to list custom channels.
     * @return the request
     */
    public List list(java.lang.String adClientId) throws java.io.IOException {
      List result = new List(adClientId);
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.CustomChannels> {

      private static final String REST_PATH = "adclients/{adClientId}/customchannels";

      /**
       * List all custom channels in the specified ad client for this AdSense account.
       *
       * Create a request for the method "customchannels.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to list custom channels.
       * @since 1.13
       */
      protected List(java.lang.String adClientId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.CustomChannels.class);
        this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Ad client for which to list custom channels. */
      @com.google.api.client.util.Key
      private java.lang.String adClientId;

      /** Ad client for which to list custom channels.
       */
      public java.lang.String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to list custom channels. */
      public List setAdClientId(java.lang.String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /**
       * A continuation token, used to page through custom channels. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** A continuation token, used to page through custom channels. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * A continuation token, used to page through custom channels. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of custom channels to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of custom channels to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of custom channels to include in the response, used for paging. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the Adunits collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Adunits.List request = adsense.adunits().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Adunits adunits() {
      return new Adunits();
    }

    /**
     * The "adunits" collection of methods.
     */
    public class Adunits {

      /**
       * List all ad units in the specified custom channel.
       *
       * Create a request for the method "adunits.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param adClientId Ad client which contains the custom channel.
       * @param customChannelId Custom channel for which to list ad units.
       * @return the request
       */
      public List list(java.lang.String adClientId, java.lang.String customChannelId) throws java.io.IOException {
        List result = new List(adClientId, customChannelId);
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.AdUnits> {

        private static final String REST_PATH = "adclients/{adClientId}/customchannels/{customChannelId}/adunits";

        /**
         * List all ad units in the specified custom channel.
         *
         * Create a request for the method "adunits.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param adClientId Ad client which contains the custom channel.
         * @param customChannelId Custom channel for which to list ad units.
         * @since 1.13
         */
        protected List(java.lang.String adClientId, java.lang.String customChannelId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdUnits.class);
          this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
          this.customChannelId = com.google.api.client.util.Preconditions.checkNotNull(customChannelId, "Required parameter customChannelId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** Ad client which contains the custom channel. */
        @com.google.api.client.util.Key
        private java.lang.String adClientId;

        /** Ad client which contains the custom channel.
         */
        public java.lang.String getAdClientId() {
          return adClientId;
        }

        /** Ad client which contains the custom channel. */
        public List setAdClientId(java.lang.String adClientId) {
          this.adClientId = adClientId;
          return this;
        }

        /** Custom channel for which to list ad units. */
        @com.google.api.client.util.Key
        private java.lang.String customChannelId;

        /** Custom channel for which to list ad units.
         */
        public java.lang.String getCustomChannelId() {
          return customChannelId;
        }

        /** Custom channel for which to list ad units. */
        public List setCustomChannelId(java.lang.String customChannelId) {
          this.customChannelId = customChannelId;
          return this;
        }

        /** Whether to include inactive ad units. Default: true. */
        @com.google.api.client.util.Key
        private java.lang.Boolean includeInactive;

        /** Whether to include inactive ad units. Default: true.
         */
        public java.lang.Boolean getIncludeInactive() {
          return includeInactive;
        }

        /** Whether to include inactive ad units. Default: true. */
        public List setIncludeInactive(java.lang.Boolean includeInactive) {
          this.includeInactive = includeInactive;
          return this;
        }

        /**
         * A continuation token, used to page through ad units. To retrieve the next page, set this
         * parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through ad units. To retrieve the next page, set this parameter
       to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through ad units. To retrieve the next page, set this
         * parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of ad units to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of ad units to include in the response, used for paging.

       [minimum: 0] [maximum: 10000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of ad units to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the Metadata collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Metadata.List request = adsense.metadata().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Metadata metadata() {
    return new Metadata();
  }

  /**
   * The "metadata" collection of methods.
   */
  public class Metadata {

    /**
     * An accessor for creating requests from the Dimensions collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Dimensions.List request = adsense.dimensions().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Dimensions dimensions() {
      return new Dimensions();
    }

    /**
     * The "dimensions" collection of methods.
     */
    public class Dimensions {

      /**
       * List the metadata for the dimensions available to this AdSense account.
       *
       * Create a request for the method "dimensions.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.Metadata> {

        private static final String REST_PATH = "metadata/dimensions";

        /**
         * List the metadata for the dimensions available to this AdSense account.
         *
         * Create a request for the method "dimensions.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.Metadata.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
    /**
     * An accessor for creating requests from the Metrics collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Metrics.List request = adsense.metrics().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Metrics metrics() {
      return new Metrics();
    }

    /**
     * The "metrics" collection of methods.
     */
    public class Metrics {

      /**
       * List the metadata for the metrics available to this AdSense account.
       *
       * Create a request for the method "metrics.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.Metadata> {

        private static final String REST_PATH = "metadata/metrics";

        /**
         * List the metadata for the metrics available to this AdSense account.
         *
         * Create a request for the method "metrics.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.Metadata.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the Reports collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Reports.List request = adsense.reports().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Reports reports() {
    return new Reports();
  }

  /**
   * The "reports" collection of methods.
   */
  public class Reports {

    /**
     * Generate an AdSense report based on the report request sent in the query parameters. Returns the
     * result as JSON; to retrieve output in CSV format specify "alt=csv" as a query parameter.
     *
     * Create a request for the method "reports.generate".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link Generate#execute()} method to invoke the remote operation.
     *
     * @param startDate Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
     * @param endDate End of the date range to report on in "YYYY-MM-DD" format, inclusive.
     * @return the request
     */
    public Generate generate(java.lang.String startDate, java.lang.String endDate) throws java.io.IOException {
      Generate result = new Generate(startDate, endDate);
      initialize(result);
      return result;
    }

    public class Generate extends AdSenseRequest<com.google.api.services.adsense.model.AdsenseReportsGenerateResponse> {

      private static final String REST_PATH = "reports";

      private final java.util.regex.Pattern STARTDATE_PATTERN =
          java.util.regex.Pattern.compile("\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");

      private final java.util.regex.Pattern ENDDATE_PATTERN =
          java.util.regex.Pattern.compile("\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");

      private final java.util.regex.Pattern SORT_PATTERN =
          java.util.regex.Pattern.compile("(\\+|-)?[a-zA-Z_]+");

      private final java.util.regex.Pattern LOCALE_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+");

      private final java.util.regex.Pattern METRIC_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+");

      private final java.util.regex.Pattern FILTER_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+(==|=@).+");

      private final java.util.regex.Pattern CURRENCY_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z]+");

      private final java.util.regex.Pattern DIMENSION_PATTERN =
          java.util.regex.Pattern.compile("[a-zA-Z_]+");

      /**
       * Generate an AdSense report based on the report request sent in the query parameters. Returns
       * the result as JSON; to retrieve output in CSV format specify "alt=csv" as a query parameter.
       *
       * Create a request for the method "reports.generate".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Generate#execute()} method to invoke the remote operation. <p>
       * {@link
       * Generate#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param startDate Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
       * @param endDate End of the date range to report on in "YYYY-MM-DD" format, inclusive.
       * @since 1.13
       */
      protected Generate(java.lang.String startDate, java.lang.String endDate) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdsenseReportsGenerateResponse.class);
        this.startDate = com.google.api.client.util.Preconditions.checkNotNull(startDate, "Required parameter startDate must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(STARTDATE_PATTERN.matcher(startDate).matches(),
              "Parameter startDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        this.endDate = com.google.api.client.util.Preconditions.checkNotNull(endDate, "Required parameter endDate must be specified.");
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(ENDDATE_PATTERN.matcher(endDate).matches(),
              "Parameter endDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        initializeMediaDownload();
      }

      @Override
      public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
        super.executeMediaAndDownloadTo(outputStream);
      }

      @Override
      public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
        return super.executeMediaAsInputStream();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
        return super.executeMedia();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Generate setAlt(java.lang.String alt) {
        return (Generate) super.setAlt(alt);
      }

      @Override
      public Generate setFields(java.lang.String fields) {
        return (Generate) super.setFields(fields);
      }

      @Override
      public Generate setKey(java.lang.String key) {
        return (Generate) super.setKey(key);
      }

      @Override
      public Generate setOauthToken(java.lang.String oauthToken) {
        return (Generate) super.setOauthToken(oauthToken);
      }

      @Override
      public Generate setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Generate) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Generate setQuotaUser(java.lang.String quotaUser) {
        return (Generate) super.setQuotaUser(quotaUser);
      }

      @Override
      public Generate setUserIp(java.lang.String userIp) {
        return (Generate) super.setUserIp(userIp);
      }

      /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      @com.google.api.client.util.Key
      private java.lang.String startDate;

      /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive.
       */
      public java.lang.String getStartDate() {
        return startDate;
      }

      /** Start of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      public Generate setStartDate(java.lang.String startDate) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(STARTDATE_PATTERN.matcher(startDate).matches(),
              "Parameter startDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        this.startDate = startDate;
        return this;
      }

      /** End of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      @com.google.api.client.util.Key
      private java.lang.String endDate;

      /** End of the date range to report on in "YYYY-MM-DD" format, inclusive.
       */
      public java.lang.String getEndDate() {
        return endDate;
      }

      /** End of the date range to report on in "YYYY-MM-DD" format, inclusive. */
      public Generate setEndDate(java.lang.String endDate) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(ENDDATE_PATTERN.matcher(endDate).matches(),
              "Parameter endDate must conform to the pattern " +
              "\\d{4}-\\d{2}-\\d{2}|(today|startOfMonth|startOfYear)(([\\-\\+]\\d+[dwmy]){0,2}?)");
        }
        this.endDate = endDate;
        return this;
      }

      /**
       * The name of a dimension or metric to sort the resulting report on, optionally prefixed with
       * "+" to sort ascending or "-" to sort descending. If no prefix is specified, the column is
       * sorted ascending.
       */
      @com.google.api.client.util.Key
      private java.util.List<java.lang.String> sort;

      /** The name of a dimension or metric to sort the resulting report on, optionally prefixed with "+" to
     sort ascending or "-" to sort descending. If no prefix is specified, the column is sorted
     ascending.
       */
      public java.util.List<java.lang.String> getSort() {
        return sort;
      }

      /**
       * The name of a dimension or metric to sort the resulting report on, optionally prefixed with
       * "+" to sort ascending or "-" to sort descending. If no prefix is specified, the column is
       * sorted ascending.
       */
      public Generate setSort(java.util.List<java.lang.String> sort) {
        if (!getSuppressPatternChecks()) {
          for (String sortElem : sort) {
            com.google.api.client.util.Preconditions.checkArgument(SORT_PATTERN.matcher(sortElem).matches(),
                "Parameter sort elements must conform to the pattern " +
                "(\\+|-)?[a-zA-Z_]+");
          }
        }
        this.sort = sort;
        return this;
      }

      /**
       * Optional locale to use for translating report output to a local language. Defaults to
       * "en_US" if not specified.
       */
      @com.google.api.client.util.Key
      private java.lang.String locale;

      /** Optional locale to use for translating report output to a local language. Defaults to "en_US" if
     not specified.
       */
      public java.lang.String getLocale() {
        return locale;
      }

      /**
       * Optional locale to use for translating report output to a local language. Defaults to
       * "en_US" if not specified.
       */
      public Generate setLocale(java.lang.String locale) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(LOCALE_PATTERN.matcher(locale).matches(),
              "Parameter locale must conform to the pattern " +
              "[a-zA-Z_]+");
        }
        this.locale = locale;
        return this;
      }

      /** Numeric columns to include in the report. */
      @com.google.api.client.util.Key
      private java.util.List<java.lang.String> metric;

      /** Numeric columns to include in the report.
       */
      public java.util.List<java.lang.String> getMetric() {
        return metric;
      }

      /** Numeric columns to include in the report. */
      public Generate setMetric(java.util.List<java.lang.String> metric) {
        if (!getSuppressPatternChecks()) {
          for (String metricElem : metric) {
            com.google.api.client.util.Preconditions.checkArgument(METRIC_PATTERN.matcher(metricElem).matches(),
                "Parameter metric elements must conform to the pattern " +
                "[a-zA-Z_]+");
          }
        }
        this.metric = metric;
        return this;
      }

      /** The maximum number of rows of report data to return. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of rows of report data to return.

     [minimum: 0] [maximum: 50000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of rows of report data to return. */
      public Generate setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** Filters to be run on the report. */
      @com.google.api.client.util.Key
      private java.util.List<java.lang.String> filter;

      /** Filters to be run on the report.
       */
      public java.util.List<java.lang.String> getFilter() {
        return filter;
      }

      /** Filters to be run on the report. */
      public Generate setFilter(java.util.List<java.lang.String> filter) {
        if (!getSuppressPatternChecks()) {
          for (String filterElem : filter) {
            com.google.api.client.util.Preconditions.checkArgument(FILTER_PATTERN.matcher(filterElem).matches(),
                "Parameter filter elements must conform to the pattern " +
                "[a-zA-Z_]+(==|=@).+");
          }
        }
        this.filter = filter;
        return this;
      }

      /**
       * Optional currency to use when reporting on monetary metrics. Defaults to the account's
       * currency if not set.
       */
      @com.google.api.client.util.Key
      private java.lang.String currency;

      /** Optional currency to use when reporting on monetary metrics. Defaults to the account's currency if
     not set.
       */
      public java.lang.String getCurrency() {
        return currency;
      }

      /**
       * Optional currency to use when reporting on monetary metrics. Defaults to the account's
       * currency if not set.
       */
      public Generate setCurrency(java.lang.String currency) {
        if (!getSuppressPatternChecks()) {
          com.google.api.client.util.Preconditions.checkArgument(CURRENCY_PATTERN.matcher(currency).matches(),
              "Parameter currency must conform to the pattern " +
              "[a-zA-Z]+");
        }
        this.currency = currency;
        return this;
      }

      /** Index of the first row of report data to return. */
      @com.google.api.client.util.Key
      private java.lang.Integer startIndex;

      /** Index of the first row of report data to return.

     [minimum: 0] [maximum: 5000]
       */
      public java.lang.Integer getStartIndex() {
        return startIndex;
      }

      /** Index of the first row of report data to return. */
      public Generate setStartIndex(java.lang.Integer startIndex) {
        this.startIndex = startIndex;
        return this;
      }

      /**
       * Whether the report should be generated in the AdSense account's local timezone. If false
       * default PST/PDT timezone will be used.
       */
      @com.google.api.client.util.Key
      private java.lang.Boolean useTimezoneReporting;

      /** Whether the report should be generated in the AdSense account's local timezone. If false default
     PST/PDT timezone will be used.
       */
      public java.lang.Boolean getUseTimezoneReporting() {
        return useTimezoneReporting;
      }

      /**
       * Whether the report should be generated in the AdSense account's local timezone. If false
       * default PST/PDT timezone will be used.
       */
      public Generate setUseTimezoneReporting(java.lang.Boolean useTimezoneReporting) {
        this.useTimezoneReporting = useTimezoneReporting;
        return this;
      }

      /** Dimensions to base the report on. */
      @com.google.api.client.util.Key
      private java.util.List<java.lang.String> dimension;

      /** Dimensions to base the report on.
       */
      public java.util.List<java.lang.String> getDimension() {
        return dimension;
      }

      /** Dimensions to base the report on. */
      public Generate setDimension(java.util.List<java.lang.String> dimension) {
        if (!getSuppressPatternChecks()) {
          for (String dimensionElem : dimension) {
            com.google.api.client.util.Preconditions.checkArgument(DIMENSION_PATTERN.matcher(dimensionElem).matches(),
                "Parameter dimension elements must conform to the pattern " +
                "[a-zA-Z_]+");
          }
        }
        this.dimension = dimension;
        return this;
      }

      /** Accounts upon which to report. */
      @com.google.api.client.util.Key
      private java.util.List<java.lang.String> accountId;

      /** Accounts upon which to report.
       */
      public java.util.List<java.lang.String> getAccountId() {
        return accountId;
      }

      /** Accounts upon which to report. */
      public Generate setAccountId(java.util.List<java.lang.String> accountId) {
        this.accountId = accountId;
        return this;
      }

      @Override
      public Generate set(String parameterName, Object value) {
        return (Generate) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the Saved collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code AdSense adsense = new AdSense(...);}
     *   {@code AdSense.Saved.List request = adsense.saved().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Saved saved() {
      return new Saved();
    }

    /**
     * The "saved" collection of methods.
     */
    public class Saved {

      /**
       * Generate an AdSense report based on the saved report ID sent in the query parameters.
       *
       * Create a request for the method "saved.generate".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Generate#execute()} method to invoke the remote operation.
       *
       * @param savedReportId The saved report to retrieve.
       * @return the request
       */
      public Generate generate(java.lang.String savedReportId) throws java.io.IOException {
        Generate result = new Generate(savedReportId);
        initialize(result);
        return result;
      }

      public class Generate extends AdSenseRequest<com.google.api.services.adsense.model.AdsenseReportsGenerateResponse> {

        private static final String REST_PATH = "reports/{savedReportId}";

        private final java.util.regex.Pattern LOCALE_PATTERN =
            java.util.regex.Pattern.compile("[a-zA-Z_]+");

        /**
         * Generate an AdSense report based on the saved report ID sent in the query parameters.
         *
         * Create a request for the method "saved.generate".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link Generate#execute()} method to invoke the remote operation. <p>
         * {@link
         * Generate#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param savedReportId The saved report to retrieve.
         * @since 1.13
         */
        protected Generate(java.lang.String savedReportId) {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.AdsenseReportsGenerateResponse.class);
          this.savedReportId = com.google.api.client.util.Preconditions.checkNotNull(savedReportId, "Required parameter savedReportId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Generate setAlt(java.lang.String alt) {
          return (Generate) super.setAlt(alt);
        }

        @Override
        public Generate setFields(java.lang.String fields) {
          return (Generate) super.setFields(fields);
        }

        @Override
        public Generate setKey(java.lang.String key) {
          return (Generate) super.setKey(key);
        }

        @Override
        public Generate setOauthToken(java.lang.String oauthToken) {
          return (Generate) super.setOauthToken(oauthToken);
        }

        @Override
        public Generate setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Generate) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Generate setQuotaUser(java.lang.String quotaUser) {
          return (Generate) super.setQuotaUser(quotaUser);
        }

        @Override
        public Generate setUserIp(java.lang.String userIp) {
          return (Generate) super.setUserIp(userIp);
        }

        /** The saved report to retrieve. */
        @com.google.api.client.util.Key
        private java.lang.String savedReportId;

        /** The saved report to retrieve.
         */
        public java.lang.String getSavedReportId() {
          return savedReportId;
        }

        /** The saved report to retrieve. */
        public Generate setSavedReportId(java.lang.String savedReportId) {
          this.savedReportId = savedReportId;
          return this;
        }

        /**
         * Optional locale to use for translating report output to a local language. Defaults to
         * "en_US" if not specified.
         */
        @com.google.api.client.util.Key
        private java.lang.String locale;

        /** Optional locale to use for translating report output to a local language. Defaults to "en_US" if
       not specified.
         */
        public java.lang.String getLocale() {
          return locale;
        }

        /**
         * Optional locale to use for translating report output to a local language. Defaults to
         * "en_US" if not specified.
         */
        public Generate setLocale(java.lang.String locale) {
          if (!getSuppressPatternChecks()) {
            com.google.api.client.util.Preconditions.checkArgument(LOCALE_PATTERN.matcher(locale).matches(),
                "Parameter locale must conform to the pattern " +
                "[a-zA-Z_]+");
          }
          this.locale = locale;
          return this;
        }

        /** Index of the first row of report data to return. */
        @com.google.api.client.util.Key
        private java.lang.Integer startIndex;

        /** Index of the first row of report data to return.

       [minimum: 0] [maximum: 5000]
         */
        public java.lang.Integer getStartIndex() {
          return startIndex;
        }

        /** Index of the first row of report data to return. */
        public Generate setStartIndex(java.lang.Integer startIndex) {
          this.startIndex = startIndex;
          return this;
        }

        /** The maximum number of rows of report data to return. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of rows of report data to return.

       [minimum: 0] [maximum: 50000]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of rows of report data to return. */
        public Generate setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public Generate set(String parameterName, Object value) {
          return (Generate) super.set(parameterName, value);
        }
      }
      /**
       * List all saved reports in this AdSense account.
       *
       * Create a request for the method "saved.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @return the request
       */
      public List list() throws java.io.IOException {
        List result = new List();
        initialize(result);
        return result;
      }

      public class List extends AdSenseRequest<com.google.api.services.adsense.model.SavedReports> {

        private static final String REST_PATH = "reports/saved";

        /**
         * List all saved reports in this AdSense account.
         *
         * Create a request for the method "saved.list".
         *
         * This request holds the parameters needed by the the adsense server.  After setting any optional
         * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
         * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
         * called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @since 1.13
         */
        protected List() {
          super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.SavedReports.class);
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /**
         * A continuation token, used to page through saved reports. To retrieve the next page, set
         * this parameter to the value of "nextPageToken" from the previous response.
         */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** A continuation token, used to page through saved reports. To retrieve the next page, set this
       parameter to the value of "nextPageToken" from the previous response.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /**
         * A continuation token, used to page through saved reports. To retrieve the next page, set
         * this parameter to the value of "nextPageToken" from the previous response.
         */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** The maximum number of saved reports to include in the response, used for paging. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** The maximum number of saved reports to include in the response, used for paging.

       [minimum: 0] [maximum: 100]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** The maximum number of saved reports to include in the response, used for paging. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the Savedadstyles collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Savedadstyles.List request = adsense.savedadstyles().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Savedadstyles savedadstyles() {
    return new Savedadstyles();
  }

  /**
   * The "savedadstyles" collection of methods.
   */
  public class Savedadstyles {

    /**
     * Get a specific saved ad style from the user's account.
     *
     * Create a request for the method "savedadstyles.get".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param savedAdStyleId Saved ad style to retrieve.
     * @return the request
     */
    public Get get(java.lang.String savedAdStyleId) throws java.io.IOException {
      Get result = new Get(savedAdStyleId);
      initialize(result);
      return result;
    }

    public class Get extends AdSenseRequest<com.google.api.services.adsense.model.SavedAdStyle> {

      private static final String REST_PATH = "savedadstyles/{savedAdStyleId}";

      /**
       * Get a specific saved ad style from the user's account.
       *
       * Create a request for the method "savedadstyles.get".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link Get#execute()} method to invoke the remote operation. <p> {@link
       * Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param savedAdStyleId Saved ad style to retrieve.
       * @since 1.13
       */
      protected Get(java.lang.String savedAdStyleId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.SavedAdStyle.class);
        this.savedAdStyleId = com.google.api.client.util.Preconditions.checkNotNull(savedAdStyleId, "Required parameter savedAdStyleId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Saved ad style to retrieve. */
      @com.google.api.client.util.Key
      private java.lang.String savedAdStyleId;

      /** Saved ad style to retrieve.
       */
      public java.lang.String getSavedAdStyleId() {
        return savedAdStyleId;
      }

      /** Saved ad style to retrieve. */
      public Get setSavedAdStyleId(java.lang.String savedAdStyleId) {
        this.savedAdStyleId = savedAdStyleId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * List all saved ad styles in the user's account.
     *
     * Create a request for the method "savedadstyles.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.SavedAdStyles> {

      private static final String REST_PATH = "savedadstyles";

      /**
       * List all saved ad styles in the user's account.
       *
       * Create a request for the method "savedadstyles.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.SavedAdStyles.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /**
       * A continuation token, used to page through saved ad styles. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** A continuation token, used to page through saved ad styles. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * A continuation token, used to page through saved ad styles. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of saved ad styles to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of saved ad styles to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of saved ad styles to include in the response, used for paging. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Urlchannels collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code AdSense adsense = new AdSense(...);}
   *   {@code AdSense.Urlchannels.List request = adsense.urlchannels().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Urlchannels urlchannels() {
    return new Urlchannels();
  }

  /**
   * The "urlchannels" collection of methods.
   */
  public class Urlchannels {

    /**
     * List all URL channels in the specified ad client for this AdSense account.
     *
     * Create a request for the method "urlchannels.list".
     *
     * This request holds the parameters needed by the the adsense server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param adClientId Ad client for which to list URL channels.
     * @return the request
     */
    public List list(java.lang.String adClientId) throws java.io.IOException {
      List result = new List(adClientId);
      initialize(result);
      return result;
    }

    public class List extends AdSenseRequest<com.google.api.services.adsense.model.UrlChannels> {

      private static final String REST_PATH = "adclients/{adClientId}/urlchannels";

      /**
       * List all URL channels in the specified ad client for this AdSense account.
       *
       * Create a request for the method "urlchannels.list".
       *
       * This request holds the parameters needed by the the adsense server.  After setting any optional
       * parameters, call the {@link List#execute()} method to invoke the remote operation. <p> {@link
       * List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must be
       * called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param adClientId Ad client for which to list URL channels.
       * @since 1.13
       */
      protected List(java.lang.String adClientId) {
        super(AdSense.this, "GET", REST_PATH, null, com.google.api.services.adsense.model.UrlChannels.class);
        this.adClientId = com.google.api.client.util.Preconditions.checkNotNull(adClientId, "Required parameter adClientId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Ad client for which to list URL channels. */
      @com.google.api.client.util.Key
      private java.lang.String adClientId;

      /** Ad client for which to list URL channels.
       */
      public java.lang.String getAdClientId() {
        return adClientId;
      }

      /** Ad client for which to list URL channels. */
      public List setAdClientId(java.lang.String adClientId) {
        this.adClientId = adClientId;
        return this;
      }

      /**
       * A continuation token, used to page through URL channels. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** A continuation token, used to page through URL channels. To retrieve the next page, set this
     parameter to the value of "nextPageToken" from the previous response.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /**
       * A continuation token, used to page through URL channels. To retrieve the next page, set
       * this parameter to the value of "nextPageToken" from the previous response.
       */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of URL channels to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of URL channels to include in the response, used for paging.

     [minimum: 0] [maximum: 10000]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** The maximum number of URL channels to include in the response, used for paging. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * Builder for {@link AdSense}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link AdSense}. */
    @Override
    public AdSense build() {
      return new AdSense(this);
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link AdSenseRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setAdSenseRequestInitializer(
        AdSenseRequestInitializer adsenseRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(adsenseRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
